@@ -8,7 +8,10 @@ from allianceauth.services.hooks import get_extension_logger
 from app_utils.logging import LoggerAddTag
 
 from .. import __title__
-from ..app_settings import MININGTAXES_TAX_ONLY_CORP_MOONS
+from ..app_settings import (
+    MININGTAXES_CORP_WALLET_DIVISION,
+    MININGTAXES_TAX_ONLY_CORP_MOONS,
+)
 from ..decorators import fetch_token_for_character
 from ..providers import esi
 from .character import CharacterAbstract
@@ -106,7 +109,7 @@ class AdminCharacter(CharacterAbstract):
         entries = (
             esi.client.Wallet.get_corporations_corporation_id_wallets_division_journal(
                 corporation_id=self.eve_character.corporation_id,
-                division=1,
+                division=MININGTAXES_CORP_WALLET_DIVISION,
                 token=token.valid_access_token(),
             ).results()
         )
