@@ -22,6 +22,9 @@ from .app_settings import (
     MININGTAXES_PING_SECOND_MSG,
     MININGTAXES_PING_THRESHOLD,
     MININGTAXES_PRICE_JANICE_API_KEY,
+    MININGTAXES_PRICE_JANICE_BUY,
+    MININGTAXES_PRICE_JANICE_SELL,
+    MININGTAXES_PRICE_JANICE_TIMING,
     MININGTAXES_PRICE_METHOD,
     MININGTAXES_PRICE_SOURCE_ID,
     MININGTAXES_PRICE_SOURCE_NAME,
@@ -264,8 +267,20 @@ def get_bulk_prices(type_ids):
         output = {}
         for item in r:
             output[str(item["itemType"]["eid"])] = {
-                "buy": {"max": str(item["top5AveragePrices"]["buyPrice5DayMedian"])},
-                "sell": {"min": str(item["top5AveragePrices"]["sellPrice5DayMedian"])},
+                "buy": {
+                    "max": str(
+                        item[MININGTAXES_PRICE_JANICE_TIMING][
+                            MININGTAXES_PRICE_JANICE_BUY
+                        ]
+                    )
+                },
+                "sell": {
+                    "min": str(
+                        item[MININGTAXES_PRICE_JANICE_TIMING][
+                            MININGTAXES_PRICE_JANICE_SELL
+                        ]
+                    )
+                },
             }
         r = output
     else:
@@ -274,8 +289,7 @@ def get_bulk_prices(type_ids):
 
 
 @shared_task(**{**TASK_DEFAULT_KWARGS, **{"bind": True}})
-def update_all_prices(self):
-
+def update_all_prices(self, force=[]):
     type_ids = []
     market_data = {}
     api_up = True
@@ -283,6 +297,13 @@ def update_all_prices(self):
     # Get all type ids by known groups
     prices = []
     added = set()
+
+    for tid in force:
+        EveType.objects.update_or_create_esi(id=tid)
+        e = EveType.objects.get(id=tid)
+        added.add(tid)
+        prices.append(e)
+
     for grp in PriceGroups().groups:
         EveGroup.objects.get_or_create_esi(
             id=grp,
@@ -296,6 +317,12 @@ def update_all_prices(self):
             added.add(it.id)
             prices.append(it)
 
+    for o in OrePrices.objects.all():
+        if o.eve_type_id in added:
+            continue
+        added.add(o.eve_type_id)
+        prices.append(o.eve_type)
+
     # Update EveUniverse objects
     matset = set()
     for item in prices:
