@@ -628,7 +628,8 @@ def char_mining_ledger_data(request, character_pk: int) -> JsonResponse:
 @permission_required("miningtaxes.basic_access")
 def curmonthgraph(request) -> JsonResponse:
     s = Stats.load()
-    return JsonResponse(s.get_curmonth_leadergraph())
+    dat = s.get_curmonth_leadergraph()
+    return JsonResponse(dat)
 
 
 @login_required
